@@ -2,13 +2,14 @@ package Devel::ebug::Wx::Service::CodeDisplay;
 
 use strict;
 use base qw(Devel::ebug::Wx::Service::Base);
+use Devel::ebug::Wx::Plugin qw(:plugin);
 
 use Devel::ebug::Wx::ServiceManager::Holder;
 use Devel::ebug::Wx::View::Code::STC;
 
 __PACKAGE__->mk_accessors( qw(code_display) );
 
-sub service_name { 'code_display' }
+sub service_name : Service { 'code_display' }
 
 sub initialize {
     my( $self, $manager ) = @_;
